extractor.SimpleExtractor

|  | ## Cheshire3 Object Model: Class SimpleExtractor

Module extractor :: Class SimpleExtractor

## Class SimpleExtractor
source code

Object Tree:

               object --+
                        |
    configParser.C3Object --+
                            |
        baseObjects.Extractor --+
                                |
                               SimpleExtractor

Known Subclasses:
  DateExtractor, KeywordExtractor

Base extractor. Extracts exact text
Instance Methods

__init__(self, session, config, parent) The constructor for all Cheshire3 objects take the same arguments: session: A Session object topNode: The <config> or <subConfig> domNode for the configuration parent: The object that provides the scope for this object.
process_string(self, session, data) Process a raw string, eg from an attribute value or the query.
process_node(self, session, data) Process a DOM node.
process_eventList(self, session, data) Process a list of SAX events serialised in C3 internal format.
_mergeHash(self, a, b)
process_xpathResult(self, session, data) Process the result of an XPath expression.
Inherited from `configParser.C3Object`: `auth_function`, `get_config`, `get_default`, `get_object`, `get_path`, `get_setting`, `log_function`, `unauth_function`, `unlog_function` Inherited from `configParser.C3Object` (private): `_getDomFromFile`, `_handleConfigNode`, `_parseIncludes`, `_recurseSubConfigs`, `_verifyDefault`, `_verifyOption`, `_verifySetting` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Class Variables

Inherited from `configParser.C3Object`: `configStore`, `defaults`, `functionLogger`, `id`, `name`, `objectType`, `objects`, `parent`, `paths`, `permissionHandlers`, `settings`, `subConfigs`, `unresolvedObjects` Inherited from `configParser.C3Object` (private): `_includeConfigStores`, `_objectRefs` Inherited from `object`: `__class__`

Method Details

### __init__(self, session, config, parent) (Constructor) | source code
The constructor for all Cheshire3 objects take the same arguments: session: A Session object topNode: The <config> or <subConfig> domNode for the configuration parent: The object that provides the scope for this object. Overrides: configParser.C3Object.__init__ (inherited documentation)

### process_string(self, session, data) | source code
Process a raw string, eg from an attribute value or the query. Overrides: baseObjects.Extractor.process_string (inherited documentation)

### process_node(self, session, data) | source code
Process a DOM node. Overrides: baseObjects.Extractor.process_node (inherited documentation)

### process_eventList(self, session, data) | source code
Process a list of SAX events serialised in C3 internal format. Overrides: baseObjects.Extractor.process_eventList (inherited documentation)

### _mergeHash(self, a, b) | source code

### process_xpathResult(self, session, data) | source code
Process the result of an XPath expression. Convenience function to wrap the other process_* functions and do type checking. Overrides: baseObjects.Extractor.process_xpathResult (inherited documentation)